"""Lucia package initializer.

Exposes core interfaces and singleton factories for LLM clients, extractors,
embeddings, vector stores, and knowledge/search pipelines.
"""

# Stores
from .stores.info_store import InfoStore
from .stores.info_store_neo4j import Neo4jInfoStore

# Clients
from .clients.llm_client import LLMClient
from .clients.openai_client import OpenAIClient

# Extractors (optional)
from .extractors.extractor import InfoExtractor, KeywordExtractor
from .extractors.noop_extractor import NoOpInfoExtractor, NoOpKeywordExtractor
from .extractors.openai_extractors import OpenAIInfoExtractor, OpenAIKeywordExtractor 

# Embeddings
from .embeddings.embedding_client import EmbeddingClient
from .embeddings.openai_embedding_client import OpenAIEmbeddingClient

# Vector Stores
from .vectorstores.vector_store import VectorStore
from .vectorstores.milvus_vector_store import MilvusVectorStore

# Extractor models and implementations
from .extractors.models import ExtractedInfo, ExtractedInfoList

# Pipelines
from .pipelines.knowledge_pipeline import KnowledgePipeline

# Prompts
from .prompts import info_extraction_system_prompt, keyword_extraction_system_prompt
